abortable

Attribute Macro abortable 

#[abortable]
Marker for api functions that will provide producer with AbortionToken which will be triggered when consumer aborts the request.

Abortion will be passed as the last argument of the producer method as abortion_token: AbortionToken.