pub enum ShutdownType {
Closed,
Shutdown,
Aborted,
Timeout,
}Expand description
Cause of producer/consumer shutdown.
Variants
Closed
Connection closed.
Shutdown
Manual shutdown.
Aborted
Abort all requests.
Timeout
Consumer/producer timed out.
NOTE: Consumer requests will not receive Error::Timeout error (they will error out with other error type like Error::Closed or Error::Shutdown). This design is deliberate to not give consumers easily determinable info about timeout duration producer was configured with.