ErrorHandler

Type Alias ErrorHandler 

pub type ErrorHandler<Response, Error> = ErrorHandler<Message<Response>, Error>;
Error handler for errors that may occur while sending or receiving messages through transport.

Aliased Type

pub struct ErrorHandler<Response, Error> {
    pub send_error_callback: Box<dyn SendErrorCallback<Message<Response>, Error>>,
    pub receive_error_callback: Box<dyn ReceiveErrorCallback<Error>>,
}

Fields

send_error_callback: Box<dyn SendErrorCallback<Message<Response>, Error>>

Callback called when an error is encountered while trying to send a message through the transport.

receive_error_callback: Box<dyn ReceiveErrorCallback<Error>>

Callback called when an error is encountered while trying to receive a message from the transport.