RPC over dnet transports.
Re-exports
pub use consumer::Consume;pub use consumer::StreamRequest;pub use consumer::ValueRequest;pub use dnet_base;pub use atomic_counter;pub use futures;
Modules
- consumer
- Consumer related functionality.
- parts
- Parts used internally to build RPC infrastructure for an API.
- producer
- Producer related functionality.
Structs
- Instant
- A measurement of a monotonically nondecreasing clock.
Opaque and useful only with
Duration. - Join
Handle - An owned permission to join on a task (await its termination).
- Sleep
- Future returned by
sleepandsleep_until.
Enums
- Error
- RPC error.
- Shutdown
Type - Cause of producer/consumer shutdown.
- Timeout
- Timeout future.
Traits
- Shutdown
- Helper trait for shutdown futures used by producers and consumers.
- Transport
- Helper trait for transports used by
dnet-rpc. - Transport
Error - Helper trait for consumer errors.
Functions
- sleep
- Waits until
durationhas elapsed. - spawn
- Spawns a new asynchronous task, returning a
JoinHandlefor it.
Attribute Macros
- abortable
- Marker for api functions that will provide producer with AbortionToken which will be triggered when consumer aborts the request.
- api
- Macro for marking traits defining api’s interface.
- no_ack
- Marker for api functions that are “fire-and-forget” - they return as soon as request is sent to the producer without waiting for response - in fact producer won’t even send it.
- no_
serde - Used together with api macro, disables attachment of serde
Serializeand/orDeserializederive macros on generatedRequestand/orResponseenums.